@@ -42,7 +42,7 @@ class LocationManagerTest {
 
     private LocationManager locationManager;
 
-    final Path mockModuleInfoJava = Paths.get("src/test/resources/mock/module-info.java");
+    final Path mockModuleInfoJava = Paths.get("src/test/test-data/mock/module-info.java");
 
     @BeforeEach
     void onSetup() {
@@ -61,10 +61,10 @@ class LocationManagerTest {
         ResolvePathsResult<File> result =
                 locationManager.resolvePaths(ResolvePathsRequest.ofFiles(Collections.emptyList()));
         assertThat(result.getMainModuleDescriptor()).isNull();
-        assertThat(result.getPathElements()).hasSize(0);
-        assertThat(result.getModulepathElements()).hasSize(0);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathElements()).isEmpty();
+        assertThat(result.getModulepathElements()).isEmpty();
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
@@ -80,15 +80,15 @@ class LocationManagerTest {
         ResolvePathsResult<File> result = locationManager.resolvePaths(request);
 
         assertThat(result.getMainModuleDescriptor()).isEqualTo(descriptor);
-        assertThat(result.getPathElements()).hasSize(0);
-        assertThat(result.getModulepathElements()).hasSize(0);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathElements()).isEmpty();
+        assertThat(result.getModulepathElements()).isEmpty();
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testManifestWithReflectRequires() throws Exception {
-        Path abc = Paths.get("src/test/resources/dir.manifest.with/out");
+        Path abc = Paths.get("src/test/test-data/dir.manifest.with/out");
         JavaModuleDescriptor descriptor = JavaModuleDescriptor.newModule("base")
                 .requires("auto.by.manifest")
                 .build();
@@ -102,13 +102,13 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(1);
         assertThat(result.getModulepathElements()).hasSize(1);
         assertThat(result.getModulepathElements().get(abc)).isEqualTo(ModuleNameSource.MANIFEST);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testDirDescriptorWithReflectRequires() throws Exception {
-        Path abc = Paths.get("src/test/resources/dir.descriptor/out");
+        Path abc = Paths.get("src/test/test-data/dir.descriptor/out");
         JavaModuleDescriptor descriptor = JavaModuleDescriptor.newModule("base")
                 .requires("dir.descriptor")
                 .build();
@@ -125,13 +125,13 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(1);
         assertThat(result.getModulepathElements()).hasSize(1);
         assertThat(result.getModulepathElements().get(abc)).isEqualTo(ModuleNameSource.MODULEDESCRIPTOR);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testJarWithAsmRequires() throws Exception {
-        Path abc = Paths.get("src/test/resources/jar.descriptor/asm-6.0_BETA.jar");
+        Path abc = Paths.get("src/test/test-data/jar.descriptor/asm-6.0_BETA.jar");
         JavaModuleDescriptor descriptor = JavaModuleDescriptor.newModule("base")
                 .requires("org.objectweb.asm")
                 .build();
@@ -147,14 +147,14 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(1);
         assertThat(result.getModulepathElements()).hasSize(1);
         assertThat(result.getModulepathElements().get(abc)).isEqualTo(ModuleNameSource.MODULEDESCRIPTOR);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testIdenticalModuleNames() throws Exception {
-        Path pj1 = Paths.get("src/test/resources/jar.empty/plexus-java-1.0.0-SNAPSHOT.jar");
-        Path pj2 = Paths.get("src/test/resources/jar.empty.2/plexus-java-2.0.0-SNAPSHOT.jar");
+        Path pj1 = Paths.get("src/test/test-data/jar.empty/plexus-java-1.0.0-SNAPSHOT.jar");
+        Path pj2 = Paths.get("src/test/test-data/jar.empty.2/plexus-java-2.0.0-SNAPSHOT.jar");
         JavaModuleDescriptor descriptor =
                 JavaModuleDescriptor.newModule("base").requires("plexus.java").build();
         when(qdoxParser.fromSourcePath(any(Path.class))).thenReturn(descriptor);
@@ -183,8 +183,8 @@ class LocationManagerTest {
 
     @Test
     public void testIdenticalAutomaticModuleNames() throws Exception {
-        Path pj1 = Paths.get("src/test/resources/jar.empty/plexus-java-1.0.0-SNAPSHOT.jar");
-        Path pj2 = Paths.get("src/test/resources/jar.empty.2/plexus-java-2.0.0-SNAPSHOT.jar");
+        Path pj1 = Paths.get("src/test/test-data/jar.empty/plexus-java-1.0.0-SNAPSHOT.jar");
+        Path pj2 = Paths.get("src/test/test-data/jar.empty.2/plexus-java-2.0.0-SNAPSHOT.jar");
         JavaModuleDescriptor descriptor =
                 JavaModuleDescriptor.newModule("base").requires("plexus.java").build();
         when(qdoxParser.fromSourcePath(any(Path.class))).thenReturn(descriptor);
@@ -213,8 +213,8 @@ class LocationManagerTest {
 
     @Test
     public void testMainJarModuleAndTestJarAutomatic() throws Exception {
-        Path pj1 = Paths.get("src/test/resources/jar.tests/plexus-java-1.0.0-SNAPSHOT.jar");
-        Path pj2 = Paths.get("src/test/resources/jar.tests/plexus-java-1.0.0-SNAPSHOT-tests.jar");
+        Path pj1 = Paths.get("src/test/test-data/jar.tests/plexus-java-1.0.0-SNAPSHOT.jar");
+        Path pj2 = Paths.get("src/test/test-data/jar.tests/plexus-java-1.0.0-SNAPSHOT-tests.jar");
         JavaModuleDescriptor descriptor =
                 JavaModuleDescriptor.newModule("base").requires("plexus.java").build();
         when(qdoxParser.fromSourcePath(any(Path.class))).thenReturn(descriptor);
@@ -243,7 +243,7 @@ class LocationManagerTest {
 
     @Test
     void testNonJar() throws Exception {
-        Path p = Paths.get("src/test/resources/nonjar/pom.xml");
+        Path p = Paths.get("src/test/test-data/nonjar/pom.xml");
 
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(Collections.singletonList(p)).setMainModuleDescriptor(mockModuleInfoJava);
@@ -255,7 +255,7 @@ class LocationManagerTest {
 
     @Test
     void testAdditionalModules() throws Exception {
-        Path p = Paths.get("src/test/resources/mock/jar0.jar");
+        Path p = Paths.get("src/test/test-data/mock/jar0.jar");
 
         JavaModuleDescriptor descriptor = JavaModuleDescriptor.newModule("base").build();
         when(qdoxParser.fromSourcePath(any(Path.class))).thenReturn(descriptor);
@@ -271,13 +271,13 @@ class LocationManagerTest {
         assertThat(result.getMainModuleDescriptor()).isEqualTo(descriptor);
         assertThat(result.getPathElements()).hasSize(1);
         assertThat(result.getModulepathElements()).hasSize(1);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testResolvePath() throws Exception {
-        Path abc = Paths.get("src/test/resources/mock/jar0.jar");
+        Path abc = Paths.get("src/test/test-data/mock/jar0.jar");
         ResolvePathRequest<Path> request = ResolvePathRequest.ofPath(abc);
 
         when(asmParser.getModuleDescriptor(abc))
@@ -292,8 +292,8 @@ class LocationManagerTest {
 
     @Test
     void testNoMatchingProviders() throws Exception {
-        Path abc = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path def = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
+        Path abc = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path def = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(def).setMainModuleDescriptor(abc).setIncludeAllProviders(true);
 
@@ -306,15 +306,15 @@ class LocationManagerTest {
 
         ResolvePathsResult<Path> result = locationManager.resolvePaths(request);
         assertThat(result.getPathElements()).hasSize(1);
-        assertThat(result.getModulepathElements()).hasSize(0);
+        assertThat(result.getModulepathElements()).isEmpty();
         assertThat(result.getClasspathElements()).hasSize(1);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testMainModuleDescriptorWithProviders() throws Exception {
-        Path abc = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path def = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
+        Path abc = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path def = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(def).setMainModuleDescriptor(abc).setIncludeAllProviders(true);
 
@@ -328,14 +328,14 @@ class LocationManagerTest {
         ResolvePathsResult<Path> result = locationManager.resolvePaths(request);
         assertThat(result.getPathElements()).hasSize(1);
         assertThat(result.getModulepathElements()).hasSize(1);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testMainModuleDescriptorWithProvidersDontIncludeProviders() throws Exception {
-        Path abc = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path def = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
+        Path abc = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path def = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
         ResolvePathsRequest<Path> request = ResolvePathsRequest.ofPaths(def).setMainModuleDescriptor(abc);
 
         when(qdoxParser.fromSourcePath(abc))
@@ -347,16 +347,16 @@ class LocationManagerTest {
 
         ResolvePathsResult<Path> result = locationManager.resolvePaths(request);
         assertThat(result.getPathElements()).hasSize(1);
-        assertThat(result.getModulepathElements()).hasSize(0);
+        assertThat(result.getModulepathElements()).isEmpty();
         assertThat(result.getClasspathElements()).hasSize(1);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testTransitiveProviders() throws Exception {
-        Path abc = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path def = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path ghi = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
+        Path abc = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path def = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path ghi = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
         ResolvePathsRequest<Path> request = ResolvePathsRequest.ofPaths(def, ghi)
                 .setMainModuleDescriptor(abc)
                 .setIncludeAllProviders(true);
@@ -374,15 +374,15 @@ class LocationManagerTest {
         ResolvePathsResult<Path> result = locationManager.resolvePaths(request);
         assertThat(result.getPathElements()).hasSize(2);
         assertThat(result.getModulepathElements()).hasSize(2);
-        assertThat(result.getClasspathElements()).hasSize(0);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getClasspathElements()).isEmpty();
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testDontIncludeProviders() throws Exception {
-        Path abc = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path def = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path ghi = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
+        Path abc = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path def = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path ghi = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(def, ghi).setMainModuleDescriptor(abc);
 
@@ -400,13 +400,13 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(2);
         assertThat(result.getModulepathElements()).hasSize(1);
         assertThat(result.getClasspathElements()).hasSize(1);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testAllowAdditionalModulesWithoutMainDescriptor() throws Exception {
-        Path def = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path ghi = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
+        Path def = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path ghi = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(def, ghi).setAdditionalModules(Collections.singleton("def"));
 
@@ -419,12 +419,12 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(2);
         assertThat(result.getModulepathElements()).hasSize(1);
         assertThat(result.getClasspathElements()).hasSize(1);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testReuseModuleDescriptor() throws Exception {
-        Path def = Paths.get("src/test/resources/mock/jar0.jar");
+        Path def = Paths.get("src/test/test-data/mock/jar0.jar");
 
         ResolvePathRequest<Path> request1 = ResolvePathRequest.ofPath(def);
         when(asmParser.getModuleDescriptor(def))
@@ -442,7 +442,7 @@ class LocationManagerTest {
 
     @Test
     void testParseModuleDescriptor() throws Exception {
-        Path descriptorPath = Paths.get("src/test/resources/src.dir/module-info.java");
+        Path descriptorPath = Paths.get("src/test/test-data/src.dir/module-info.java");
         when(qdoxParser.fromSourcePath(descriptorPath))
                 .thenReturn(JavaModuleDescriptor.newModule("a.b.c").build());
 
@@ -461,9 +461,9 @@ class LocationManagerTest {
 
     @Test
     void testTransitiveStatic() throws Exception {
-        Path moduleA = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path moduleB = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path moduleC = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
+        Path moduleA = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path moduleB = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path moduleC = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(moduleB, moduleC).setMainModuleDescriptor(moduleA);
 
@@ -482,15 +482,15 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(2);
         assertThat(result.getModulepathElements()).hasSize(1);
         assertThat(result.getClasspathElements()).hasSize(1);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testDirectStatic() throws Exception {
-        Path moduleA = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path moduleB = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path moduleC = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
-        Path moduleD = Paths.get("src/test/resources/mock/jar2.jar"); // any existing file
+        Path moduleA = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path moduleB = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path moduleC = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
+        Path moduleD = Paths.get("src/test/test-data/mock/jar2.jar"); // any existing file
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(moduleB, moduleC, moduleD).setMainModuleDescriptor(moduleA);
         // .setIncludeStatic( true );
@@ -513,14 +513,14 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(3);
         assertThat(result.getModulepathElements()).containsOnlyKeys(moduleB, moduleD);
         assertThat(result.getClasspathElements()).containsOnly(moduleC);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     @Test
     void testDuplicateModule() throws Exception {
-        Path moduleA = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path moduleB = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path moduleC = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
+        Path moduleA = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path moduleB = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path moduleC = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
 
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(moduleB, moduleC).setMainModuleDescriptor(moduleA);
@@ -537,7 +537,7 @@ class LocationManagerTest {
         ResolvePathsResult<Path> result = locationManager.resolvePaths(request);
         assertThat(result.getPathElements()).hasSize(2);
         assertThat(result.getModulepathElements()).containsOnlyKeys(moduleB);
-        assertThat(result.getClasspathElements()).hasSize(0);
+        assertThat(result.getClasspathElements()).isEmpty();
         assertThat(result.getPathExceptions()).hasSize(1);
         // duplicate (module B / module C) is flagged as an error
         assertThat(result.getPathExceptions()).containsOnlyKeys(moduleC);
@@ -548,10 +548,10 @@ class LocationManagerTest {
 
     @Test
     void testStaticTransitive() throws Exception {
-        Path moduleA = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path moduleB = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path moduleC = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
-        Path moduleD = Paths.get("src/test/resources/mock/jar2.jar"); // any existing file
+        Path moduleA = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path moduleB = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path moduleC = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
+        Path moduleD = Paths.get("src/test/test-data/mock/jar2.jar"); // any existing file
         ResolvePathsRequest<Path> request =
                 ResolvePathsRequest.ofPaths(moduleB, moduleC, moduleD).setMainModuleDescriptor(moduleA);
 
@@ -565,7 +565,7 @@ class LocationManagerTest {
                         .build());
         when(asmParser.getModuleDescriptor(moduleC))
                 .thenReturn(JavaModuleDescriptor.newModule("moduleC")
-                        .requires(new HashSet<>(Arrays.asList(JavaModifier.STATIC)), "moduleD")
+                        .requires(new HashSet<>(Collections.singletonList(JavaModifier.STATIC)), "moduleD")
                         .build());
         when(asmParser.getModuleDescriptor(moduleD))
                 .thenReturn(JavaModuleDescriptor.newModule("moduleD").build());
@@ -574,7 +574,7 @@ class LocationManagerTest {
         assertThat(result.getPathElements()).hasSize(3);
         assertThat(result.getModulepathElements()).containsOnlyKeys(moduleB, moduleC);
         assertThat(result.getClasspathElements()).containsOnly(moduleD);
-        assertThat(result.getPathExceptions()).hasSize(0);
+        assertThat(result.getPathExceptions()).isEmpty();
     }
 
     /**
@@ -582,9 +582,9 @@ class LocationManagerTest {
      */
     @Test
     void includeDeeperRequiresStatic() throws Exception {
-        Path moduleA = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java
-        Path moduleB = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path moduleC = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
+        Path moduleA = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java
+        Path moduleB = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path moduleC = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
         ResolvePathsRequest<Path> request = ResolvePathsRequest.ofPaths(moduleA, moduleB, moduleC)
                 .setMainModuleDescriptor(moduleA)
                 .setIncludeStatic(true);
@@ -608,10 +608,10 @@ class LocationManagerTest {
      */
     @Test
     void includeDeeperRequiresStaticTransitive() throws Exception {
-        Path moduleA = Paths.get("src/test/resources/mock/module-info.java"); // some file called module-info.java core
-        Path moduleB = Paths.get("src/test/resources/mock/jar0.jar"); // any existing file
-        Path moduleC = Paths.get("src/test/resources/mock/jar1.jar"); // any existing file
-        Path moduleD = Paths.get("src/test/resources/mock/jar2.jar"); // any existing file
+        Path moduleA = Paths.get("src/test/test-data/mock/module-info.java"); // some file called module-info.java core
+        Path moduleB = Paths.get("src/test/test-data/mock/jar0.jar"); // any existing file
+        Path moduleC = Paths.get("src/test/test-data/mock/jar1.jar"); // any existing file
+        Path moduleD = Paths.get("src/test/test-data/mock/jar2.jar"); // any existing file
         ResolvePathsRequest<Path> request = ResolvePathsRequest.ofPaths(moduleA, moduleB, moduleC, moduleD)
                 .setMainModuleDescriptor(moduleA)
                 .setIncludeStatic(true);
